#
# spec file for package perl-Exporter-Tiny
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Exporter-Tiny
Name:           perl-Exporter-Tiny
VCS: https://src.suse.de/SLFO-pool/perl-Exporter-Tiny#67af7f1a98e00c1a42173cbc07bf597474916f5a23e12712b923cab43d971b5a
Version:        1.006002
Release:        160000.1.6
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        An exporter with the features of Sub::Exporter but only core dependencies
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/T/TO/TOBYINK/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
Exporter::Tiny supports many of Sub::Exporter's external-facing features
including renaming imported functions with the '-as', '-prefix' and
'-suffix' options; explicit destinations with the 'into' option; and
alternative installers with the 'installer' option. But it's written in
only about 40% as many lines of code and with zero non-core dependencies.

Its internal-facing interface is closer to Exporter.pm, with configuration
done through the '@EXPORT', '@EXPORT_OK' and '%EXPORT_TAGS' package
variables.

If you are trying to *write* a module that inherits from Exporter::Tiny,
then look at:

  * Exporter::Tiny::Manual::QuickStart

  * Exporter::Tiny::Manual::Exporting

If you are trying to *use* a module that inherits from Exporter::Tiny, then
look at:

  * Exporter::Tiny::Manual::Importing

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes COPYRIGHT CREDITS doap.ttl examples NEWS README TODO
%license LICENSE

%changelog
* Sat Apr  1 2023 timueller+perl@suse.de
- updated to 1.006002
  see /usr/share/doc/packages/perl-Exporter-Tiny/Changes
  Home page:    <https://exportertiny.github.io/>
* Tue Nov 22 2022 timueller+perl@suse.de
- updated to 1.006000
  see /usr/share/doc/packages/perl-Exporter-Tiny/Changes
  1.006000	2022-11-21
  [ Packaging ]
  - Stable version number.
  1.005_000	2022-10-17
  - Introduced lexical exporter support on Perl 5.11.2+ using the
    Lexical::Var module.
  - Refactored the Perl 5.37.2+ lexical exporter support.
* Sun Oct 16 2022 timueller+perl@suse.de
- updated to 1.004004
  see /usr/share/doc/packages/perl-Exporter-Tiny/Changes
  1.004004	2022-10-15
  [ Documentation ]
  - Minor corrections to QuickStart page in the manual.
* Sat Oct  1 2022 timueller+perl@suse.de
- updated to 1.004003
  see /usr/share/doc/packages/perl-Exporter-Tiny/Changes
  1.004003	2022-09-30
  [ Bug Fixes ]
  - If exporting non-CODE items which happen to have the same name as
    exported CODE items, their export was being quietly blocked. These
    exports should now work.
    Diab Jerius++
    <https://github.com/tobyink/p5-exporter-tiny/issues/9>
  - Using ! with a tag now works; it was previously documented as working
    but not implemented.
    Diab Jerius++
    <https://github.com/tobyink/p5-exporter-tiny/issues/8>
* Sat Sep 17 2022 timueller+perl@suse.de
- updated to 1.004002
  see /usr/share/doc/packages/perl-Exporter-Tiny/Changes
  1.004002	2022-09-16
  [ Test Suite ]
  - Fix for t/15nonhashvalue.t on old versions of Test::More which don't
    support `done_testing`.
  1.004001	2022-09-09
  [ Bug Fixes ]
  - Fix handling of non-hashref references in import list.
* Sat Aug 27 2022 timueller+perl@suse.de
- updated to 1.004000
  see /usr/share/doc/packages/perl-Exporter-Tiny/Changes
* Sat Apr 25 2020 timueller+perl@suse.de
- updated to 1.002002
  see /usr/share/doc/packages/perl-Exporter-Tiny/Changes
  1.002002	2020-04-24
  [ Bug Fixes ]
  - Bug in handling regexps in import lists; Exporter::Tiny allowed regexps
    like /foo/i but not /foo/. Having trailing flags is now optional!
    Tomohiro Hosaka++
    <https://github.com/tobyink/p5-exporter-tiny/issues/6>
  - Tests would fail if `PERL5OPT=-Mfeature=:5.18` environment variable was
    set. This is because bareword `-default` was being interpreted as the
    Perl `default` keyword.
    zhumengu++
    <https://github.com/tobyink/p5-exporter-tiny/issues/5>
* Wed Jul 18 2018 coolo@suse.com
- updated to 1.002001
  see /usr/share/doc/packages/perl-Exporter-Tiny/Changes
  1.002001	2018-07-17
  [ Packaging ]
  - Fix dates in changelog.
  1.002000	2018-07-17
  [ Packaging ]
  - Repackage as 1.002000.
  1.001_001	2018-06-29
  [ Test Suite ]
  - Improved test coverage, up from 88.78%% on coveralls.io to 96.74%%.
  1.001_000	2018-06-26
  - Added: Support for exporting non-code symbols such as $Foo, @Bar, and
    %%Baz.
  - Added: Support for generating non-code symbols.
* Tue Oct 17 2017 adrian.glaubitz@suse.com
- move LICENSE from %%license to %%doc to fix FTBFS on <= SLE_12_SP2
* Thu May 25 2017 coolo@suse.com
- updated to 1.000000
  see /usr/share/doc/packages/perl-Exporter-Tiny/Changes
  1.000000	2017-05-22
  [ Packaging ]
  - Repackage as 1.000000.
* Mon Feb 13 2017 coolo@suse.com
- updated to 0.044
  see /usr/share/doc/packages/perl-Exporter-Tiny/Changes
  0.044	2017-01-30
  [ Packaging ]
  - Repackage as a stable release.
  0.043_02	2017-01-30
  [ Packaging ]
  - Release using newer versions of toolchain stuff.
  0.043_01	2014-11-09
  [ Documentation ]
  - Restructure documentation.
  [ Other ]
  - Support { -as => CODE } to programatically rename functions.
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.042
  see /usr/share/doc/packages/perl-Exporter-Tiny/Changes
  0.042	2014-10-04
  [ Documentation ]
  - Document the warning emitted when you provide options to a function you
    are unimporting.
  [ Other ]
  - Housekeeping on %%TRACKED.
  0.041_02	2014-09-19
  [ Bug Fixes ]
  - Option validation needs to happen after expanding tags.
  0.041_01	2014-09-18
  - Add an `unimport` feature.
* Mon Sep 22 2014 coolo@suse.com
- updated to 0.040
  [ Packaging ]
  - Repackage as a stable release.
  0.039_01       2014-07-20
  [ Documentation ]
  - Document warning and error messages produced by Exporter::Tiny.
  [ Other ]
  - Exporter::Tiny would previously cause B.pm to be loaded into memory any
    time it exported anything. It no longer does.
  - No longer die when redefining locally defined subs.
  - Warn when redefining any subs.
  0.038  2014-04-04
  0.037_03       2014-04-02
  [ Bug Fixes ]
  - Only attempt to merge hashes if we're sure they're both really hashes!
  0.037_02       2014-04-02
  - Improved handling of hashrefs of options passed to tags, and hashrefs of
    options found within %%EXPORT_TAGS arrayrefs.
  0.037_01       2014-03-26
  [ Documentation ]
  - Fix minor error in documentation of generators.
  [ Other ]
  - Added: Support Exporter.pm's import negation syntax qw( !foo ).
  - Added: Support Exporter.pm's regexp import syntax qw( /foo/ ).
* Tue Nov 26 2013 coolo@suse.com
- initial package 0.030
  * created by cpanspec 1.78.07
